///
/// \ingroup TraceSourceList
/// \brief send ipv4 packet to outgoing interface
/// \param arg1 the trace context associated to the connected trace source.
/// \param arg2 packet sent.
/// \param arg3 index of output ipv4 interface.
///
///
/// The path to this trace source is: <b><tt>"/nodes/[0-n]/ipv4/tx"</tt></b>.
///
/// The following classes can be extracted from \p arg1 with 
/// ns3::TraceContext::GetElement:
///  - ns3::NodeListIndex
///  - ns3::Ipv4L3ProtocolTraceContextElement
void TraceSinkCallback0 (const TraceContext & arg1, Ptr<const Packet> arg2, uint32_t arg3);

///
/// \ingroup TraceSourceList
/// \brief receive ipv4 packet from incoming interface
/// \param arg1 the trace context associated to the connected trace source.
/// \param arg2 packet received.
/// \param arg3 index of input ipv4 interface.
///
///
/// The path to this trace source is: <b><tt>"/nodes/[0-n]/ipv4/rx"</tt></b>.
///
/// The following classes can be extracted from \p arg1 with 
/// ns3::TraceContext::GetElement:
///  - ns3::NodeListIndex
///  - ns3::Ipv4L3ProtocolTraceContextElement
void TraceSinkCallback1 (const TraceContext & arg1, Ptr<const Packet> arg2, uint32_t arg3);

///
/// \ingroup TraceSourceList
/// \brief drop ipv4 packet
/// \param arg1 the trace context associated to the connected trace source.
/// \param arg2 packet dropped.
///
///
/// The path to this trace source is: <b><tt>"/nodes/[0-n]/ipv4/drop"</tt></b>.
///
/// The following classes can be extracted from \p arg1 with 
/// ns3::TraceContext::GetElement:
///  - ns3::NodeListIndex
///  - ns3::Ipv4L3ProtocolTraceContextElement
void TraceSinkCallback2 (const TraceContext & arg1, Ptr<const Packet> arg2);

///
/// \ingroup TraceSourceList
/// \brief store packet in queue
/// \param arg1 the trace context associated to the connected trace source.
/// \param arg2 packet queued.
///
///
/// The path to this trace source is: <b><tt>"/nodes/[0-n]/devices/[0-n]/queue/enqueue"</tt></b>.
///
/// The following classes can be extracted from \p arg1 with 
/// ns3::TraceContext::GetElement:
///  - ns3::NodeListIndex
///  - ns3::NodeNetDeviceIndex
///  - ns3::QueueTraceType
void TraceSinkCallback3 (const TraceContext & arg1, Ptr<const Packet> arg2);

///
/// \ingroup TraceSourceList
/// \brief remove packet from queue
/// \param arg1 the trace context associated to the connected trace source.
/// \param arg2 packet dequeued.
///
///
/// The path to this trace source is: <b><tt>"/nodes/[0-n]/devices/[0-n]/queue/dequeue"</tt></b>.
///
/// The following classes can be extracted from \p arg1 with 
/// ns3::TraceContext::GetElement:
///  - ns3::NodeListIndex
///  - ns3::NodeNetDeviceIndex
///  - ns3::QueueTraceType
void TraceSinkCallback4 (const TraceContext & arg1, Ptr<const Packet> arg2);

///
/// \ingroup TraceSourceList
/// \brief drop packet from queue
/// \param arg1 the trace context associated to the connected trace source.
/// \param arg2 packet dropped.
///
///
/// The path to this trace source is: <b><tt>"/nodes/[0-n]/devices/[0-n]/queue/drop"</tt></b>.
///
/// The following classes can be extracted from \p arg1 with 
/// ns3::TraceContext::GetElement:
///  - ns3::NodeListIndex
///  - ns3::NodeNetDeviceIndex
///  - ns3::QueueTraceType
void TraceSinkCallback5 (const TraceContext & arg1, Ptr<const Packet> arg2);

///
/// \ingroup TraceSourceList
/// \brief receive MAC packet
/// \param arg1 the trace context associated to the connected trace source.
/// \param arg2 packet received.
///
///
/// The path to this trace source is: <b><tt>"/nodes/[0-n]/devices/[0-n]/rx"</tt></b>.
///
/// The following classes can be extracted from \p arg1 with 
/// ns3::TraceContext::GetElement:
///  - ns3::NodeListIndex
///  - ns3::NodeNetDeviceIndex
///  - ns3::PointToPointTraceType
void TraceSinkCallback6 (const TraceContext & arg1, Ptr<const Packet> arg2);

///
/// \ingroup TraceSourceList
/// \brief drop MAC packet
/// \param arg1 the trace context associated to the connected trace source.
/// \param arg2 packet dropped.
///
///
/// The path to this trace source is: <b><tt>"/nodes/[0-n]/devices/[0-n]/drop"</tt></b>.
///
/// The following classes can be extracted from \p arg1 with 
/// ns3::TraceContext::GetElement:
///  - ns3::NodeListIndex
///  - ns3::NodeNetDeviceIndex
///  - ns3::PointToPointTraceType
void TraceSinkCallback7 (const TraceContext & arg1, Ptr<const Packet> arg2);

///
/// \ingroup TraceSourceList
/// \brief receive MAC packet
/// \param arg1 the trace context associated to the connected trace source.
/// \param arg2 packet received.
///
///
/// The path to this trace source is: <b><tt>"/nodes/[0-n]/devices/[0-n]/rx"</tt></b>.
///
/// The following classes can be extracted from \p arg1 with 
/// ns3::TraceContext::GetElement:
///  - ns3::NodeListIndex
///  - ns3::NodeNetDeviceIndex
///  - ns3::CsmaTraceType
void TraceSinkCallback8 (const TraceContext & arg1, Ptr<const Packet> arg2);

///
/// \ingroup TraceSourceList
/// \brief drop MAC packet
/// \param arg1 the trace context associated to the connected trace source.
/// \param arg2 packet dropped.
///
///
/// The path to this trace source is: <b><tt>"/nodes/[0-n]/devices/[0-n]/drop"</tt></b>.
///
/// The following classes can be extracted from \p arg1 with 
/// ns3::TraceContext::GetElement:
///  - ns3::NodeListIndex
///  - ns3::NodeNetDeviceIndex
///  - ns3::CsmaTraceType
void TraceSinkCallback9 (const TraceContext & arg1, Ptr<const Packet> arg2);

///
/// \ingroup TraceSourceList
/// \brief The value of the position and/or velocity vector changed
/// \param arg1 the trace context associated to the connected trace source.
/// \param arg2 the mobility model whose course changed.
///
///
/// The path to this trace source is: <b><tt>"/nodes/[0-n]/$MobilityModelNotifier/course-change"</tt></b>.
///
/// The following classes can be extracted from \p arg1 with 
/// ns3::TraceContext::GetElement:
///  - ns3::NodeListIndex
void TraceSinkCallback10 (const TraceContext & arg1, Ptr<const MobilityModel> arg2);

///
/// \ingroup TraceSourceList
/// \brief send ipv4 packet to outgoing interface
/// \param arg1 the trace context associated to the connected trace source.
/// \param arg2 packet sent.
/// \param arg3 index of output ipv4 interface.
///
///
/// The path to this trace source is: <b><tt>"/nodes/[0-n]/$Ipv4L3Protocol/tx"</tt></b>.
///
/// The following classes can be extracted from \p arg1 with 
/// ns3::TraceContext::GetElement:
///  - ns3::NodeListIndex
///  - ns3::Ipv4L3ProtocolTraceContextElement
void TraceSinkCallback11 (const TraceContext & arg1, Ptr<const Packet> arg2, uint32_t arg3);

///
/// \ingroup TraceSourceList
/// \brief receive ipv4 packet from incoming interface
/// \param arg1 the trace context associated to the connected trace source.
/// \param arg2 packet received.
/// \param arg3 index of input ipv4 interface.
///
///
/// The path to this trace source is: <b><tt>"/nodes/[0-n]/$Ipv4L3Protocol/rx"</tt></b>.
///
/// The following classes can be extracted from \p arg1 with 
/// ns3::TraceContext::GetElement:
///  - ns3::NodeListIndex
///  - ns3::Ipv4L3ProtocolTraceContextElement
void TraceSinkCallback12 (const TraceContext & arg1, Ptr<const Packet> arg2, uint32_t arg3);

///
/// \ingroup TraceSourceList
/// \brief drop ipv4 packet
/// \param arg1 the trace context associated to the connected trace source.
/// \param arg2 packet dropped.
///
///
/// The path to this trace source is: <b><tt>"/nodes/[0-n]/$Ipv4L3Protocol/drop"</tt></b>.
///
/// The following classes can be extracted from \p arg1 with 
/// ns3::TraceContext::GetElement:
///  - ns3::NodeListIndex
///  - ns3::Ipv4L3ProtocolTraceContextElement
void TraceSinkCallback13 (const TraceContext & arg1, Ptr<const Packet> arg2);

/// \page ListOfDefaultValues The list of default values
/// \ingroup core
/// \defgroup ListOfDefaultValuesGroup The list of default values
/// <ul>
///  <li> \anchor DefaultValueWifiPhyStandard WifiPhyStandard
///    <ul>
///         <li>Type: (80211a|holland)</td></tr>
///         <li>Default value: 80211a</td></tr>
///         <li>Description: Describe the set of physical-layer tx modes and parameters</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiMaxSsrc WifiMaxSsrc
///    <ul>
///         <li>Type: uint32_t(0:4294967295)</td></tr>
///         <li>Default value: 7</td></tr>
///         <li>Description: The MAC maximum number of short retransmission retries (rts retransmissions).</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiMaxSlrc WifiMaxSlrc
///    <ul>
///         <li>Type: uint32_t(0:4294967295)</td></tr>
///         <li>Default value: 7</td></tr>
///         <li>Description: The MAC maximum number of long retransmission retries (data retransmissions).</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiRtsCtsThreshold WifiRtsCtsThreshold
///    <ul>
///         <li>Type: uint32_t(0:4294967295)</td></tr>
///         <li>Default value: 2000</td></tr>
///         <li>Description: The threshold (in bytes) over which rts/cts is used prior to data transmissions.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiFragmentationThreshold WifiFragmentationThreshold
///    <ul>
///         <li>Type: uint32_t(0:4294967295)</td></tr>
///         <li>Default value: 2000</td></tr>
///         <li>Description: The threshold (in bytes) over which data packets are fragmented</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiApBeaconInterval WifiApBeaconInterval
///    <ul>
///         <li>Type: (s|ms|us|ns|ps|fs)</td></tr>
///         <li>Default value: 1s</td></tr>
///         <li>Description: The interval between two consecutive beacons</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiRateControlAlgorithm WifiRateControlAlgorithm
///    <ul>
///         <li>Type: (Arf|ConstantRate|Aarf|Ideal)</td></tr>
///         <li>Default value: Arf</td></tr>
///         <li>Description: The rate control algorithm to use</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiArfSuccessThreshold WifiArfSuccessThreshold
///    <ul>
///         <li>Type: uint32_t(0:4294967295)</td></tr>
///         <li>Default value: 10</td></tr>
///         <li>Description: The minimum number of sucessfull transmissions to try a new rate.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiArfTimerThreshold WifiArfTimerThreshold
///    <ul>
///         <li>Type: uint32_t(0:4294967295)</td></tr>
///         <li>Default value: 15</td></tr>
///         <li>Description: The 'timer' threshold in the ARF algorithm.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiAarfMinSuccessThreshold WifiAarfMinSuccessThreshold
///    <ul>
///         <li>Type: uint32_t(0:4294967295)</td></tr>
///         <li>Default value: 10</td></tr>
///         <li>Description: The minimum value for the success threshold in the AARF algorithm.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiAarfMinTimerThreshold WifiAarfMinTimerThreshold
///    <ul>
///         <li>Type: uint32_t(0:4294967295)</td></tr>
///         <li>Default value: 15</td></tr>
///         <li>Description: The minimum value for the 'timer' threshold in the AARF algorithm.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiAarfSuccessK WifiAarfSuccessK
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 2</td></tr>
///         <li>Description: Multiplication factor for the success threshold in the AARF algorithm.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiAarfMaxSuccessThreshold WifiAarfMaxSuccessThreshold
///    <ul>
///         <li>Type: uint32_t(0:4294967295)</td></tr>
///         <li>Default value: 60</td></tr>
///         <li>Description: Maximum value of the success threshodl in the AARF algorithm.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiAarfTimerK WifiAarfTimerK
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 2</td></tr>
///         <li>Description: Multiplication factor for the timer threshold in the AARF algorithm.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiPhyEnergyDetectionThreshold WifiPhyEnergyDetectionThreshold
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: -140</td></tr>
///         <li>Description: The energy of a received signal should be higher than this threshold (dbm) to allow the PHY layer to detect the signal.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiPhyRxNoise WifiPhyRxNoise
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 7</td></tr>
///         <li>Description: Ratio of energy lost by receiver (dB).</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiPhyTxPowerBase WifiPhyTxPowerBase
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 16.0206</td></tr>
///         <li>Description: Minimum available transmission level (dbm).</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiPhyTxPowerEnd WifiPhyTxPowerEnd
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 16.0206</td></tr>
///         <li>Description: Maximum available transmission level (dbm).</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiPhyTxPowerLevels WifiPhyTxPowerLevels
///    <ul>
///         <li>Type: uint32_t(0:4294967295)</td></tr>
///         <li>Default value: 1</td></tr>
///         <li>Description: Number of transmission power levels available between WifiPhyTxPowerBase and WifiPhyTxPowerEnd included.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiPhyTxGain WifiPhyTxGain
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 1</td></tr>
///         <li>Description: Transmission gain (dB).</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiPhyRxGain WifiPhyRxGain
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 1</td></tr>
///         <li>Description: Reception gain (dB).</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiSsid WifiSsid
///    <ul>
///         <li>Type: string:0</td></tr>
///         <li>Default value: </td></tr>
///         <li>Description: The ssid to use. "" is the broadcast ssid.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiConstantDataRate WifiConstantDataRate
///    <ul>
///         <li>Type: (6mb|9mb|12mb|18mb|24mb|36mb|48mb|54mb)</td></tr>
///         <li>Default value: 6mb</td></tr>
///         <li>Description: The rate to use for data transmissions if using the ConstantRate rate control algorithm.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiConstantCtlRate WifiConstantCtlRate
///    <ul>
///         <li>Type: (6mb|9mb|12mb|18mb|24mb|36mb|48mb|54mb)</td></tr>
///         <li>Default value: 6mb</td></tr>
///         <li>Description: The rate to use for control transmissions if using the ConstantRate rate control algorithm.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueWifiIdealRateControlBerThreshold WifiIdealRateControlBerThreshold
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 1e-05</td></tr>
///         <li>Description: The maximum Bit Error Rate acceptable at any transmission mode</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValuePropagationLossModelType PropagationLossModelType
///    <ul>
///         <li>Type: (LogDistance|Friis|Random)</td></tr>
///         <li>Default value: LogDistance</td></tr>
///         <li>Description: The type of propagation loss model.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueFriisPropagationLossLambda FriisPropagationLossLambda
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 0.0582524</td></tr>
///         <li>Description: The wavelength to use by default for every FriisPropagationLossModel (default is 5.15 GHz at 300 000 km/s).</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueFriisPropagationLossSystemLoss FriisPropagationLossSystemLoss
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 1</td></tr>
///         <li>Description: The system loss to use by default for every FriisPropagationLossModel</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueFriisPropagationLossMinDistance FriisPropagationLossMinDistance
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 0.5</td></tr>
///         <li>Description: The distance under which the propagation model refuses to give results (m)</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomPropagationLossDistribution RandomPropagationLossDistribution
///    <ul>
///         <li>Type: (Uniform:min:max|Constant:cst)</td></tr>
///         <li>Default value: Constant:1.0</td></tr>
///         <li>Description: The distribution (in dbm) to choose the propagation loss.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueLogDistancePropagationLossExponent LogDistancePropagationLossExponent
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 3</td></tr>
///         <li>Description: The exponent of the Path Loss propagation model</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueLogDistancePropagationLossReferenceDistance LogDistancePropagationLossReferenceDistance
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 1</td></tr>
///         <li>Description: The distance at which the reference loss is calculated (m)</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueLogDistancePropagationLossReferenceType LogDistancePropagationLossReferenceType
///    <ul>
///         <li>Type: (Friis|Random)</td></tr>
///         <li>Default value: Friis</td></tr>
///         <li>Description: The type of reference propagation model.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValuePropagationDelayModelType PropagationDelayModelType
///    <ul>
///         <li>Type: (ConstantSpeed|Random)</td></tr>
///         <li>Default value: ConstantSpeed</td></tr>
///         <li>Description: The type of propagation delay model to use.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValuePropagationDelayConstantSpeed PropagationDelayConstantSpeed
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 3e+08</td></tr>
///         <li>Description: The speed (m/s) of propagation if a ConstantSpeed propagation delay model is used.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValuePropagationDelayRandomDistribution PropagationDelayRandomDistribution
///    <ul>
///         <li>Type: (Uniform:min:max|Constant:cst)</td></tr>
///         <li>Default value: Uniform:0:1.0</td></tr>
///         <li>Description: The delay distribution to use if a Random propagation delay model is used.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomDirection2dSpeed RandomDirection2dSpeed
///    <ul>
///         <li>Type: (Uniform:min:max|Constant:cst)</td></tr>
///         <li>Default value: Uniform:1:2</td></tr>
///         <li>Description: A random variable to control the speed of a RandomDirection2d mobility model.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomDirection2dPause RandomDirection2dPause
///    <ul>
///         <li>Type: (Uniform:min:max|Constant:cst)</td></tr>
///         <li>Default value: Constant:2</td></tr>
///         <li>Description: A random variable to control the duration of the pause of a RandomDiretion mobility model.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomDirection2dArea RandomDirection2dArea
///    <ul>
///         <li>Type: (xMin:xMax:yMin:yMax)</td></tr>
///         <li>Default value: -100:100:-100:100</td></tr>
///         <li>Description: The bounding area for the RandomDirection2d model.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomWalk2dMode RandomWalk2dMode
///    <ul>
///         <li>Type: (Distance|Time)</td></tr>
///         <li>Default value: Distance</td></tr>
///         <li>Description: The mode indicates the condition used to change the current speed and direction</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomWalk2dDistance RandomWalk2dDistance
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 2</td></tr>
///         <li>Description: Change current direction and speed after moving this distance.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomWalk2dTime RandomWalk2dTime
///    <ul>
///         <li>Type: (s|ms|us|ns|ps|fs)</td></tr>
///         <li>Default value: 1s</td></tr>
///         <li>Description: Change current direction and speed after moving for this delay.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomWalk2dSpeed RandomWalk2dSpeed
///    <ul>
///         <li>Type: (Uniform:min:max|Constant:cst)</td></tr>
///         <li>Default value: Uniform:2:4</td></tr>
///         <li>Description: A random variable used to pick the speed.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomWalk2dDirection RandomWalk2dDirection
///    <ul>
///         <li>Type: (Uniform:min:max|Constant:cst)</td></tr>
///         <li>Default value: Uniform:0.0:6.283184</td></tr>
///         <li>Description: A random variable used to pick the direction (gradients).</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomWalk2dBounds RandomWalk2dBounds
///    <ul>
///         <li>Type: (xMin:xMax:yMin:yMax)</td></tr>
///         <li>Default value: 0:0:100:100</td></tr>
///         <li>Description: Bounds of the area to cruise.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomWaypointSpeed RandomWaypointSpeed
///    <ul>
///         <li>Type: (Uniform:min:max|Constant:cst)</td></tr>
///         <li>Default value: Uniform:0.3:0.7</td></tr>
///         <li>Description: A random variable used to pick the speed of a random waypoint model.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomWaypointPause RandomWaypointPause
///    <ul>
///         <li>Type: (Uniform:min:max|Constant:cst)</td></tr>
///         <li>Default value: Constant:2</td></tr>
///         <li>Description: A random variable used to pick the pause of a random waypoint model.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomWaypointPosition RandomWaypointPosition
///    <ul>
///         <li>Type: (RandomRectanglePosition|RandomDiscPosition)</td></tr>
///         <li>Default value: RandomRectanglePosition</td></tr>
///         <li>Description: A random position model used to pick the next waypoint position.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomTopologyPositionType RandomTopologyPositionType
///    <ul>
///         <li>Type: (RandomRectanglePosition|RandomDiscPosition)</td></tr>
///         <li>Default value: RandomRectanglePosition</td></tr>
///         <li>Description: The type of initial random position in a 3d topology.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomTopologyMobilityType RandomTopologyMobilityType
///    <ul>
///         <li>Type: (RandomDirection2dMobilityModel|RandomWalk2dMobilityModel|RandomWaypointMobilityModel|StaticMobilityModel)</td></tr>
///         <li>Default value: StaticMobilityModel</td></tr>
///         <li>Description: The type of mobility model attached to an object in a 3d topology.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomRectanglePositionX RandomRectanglePositionX
///    <ul>
///         <li>Type: (Uniform:min:max|Constant:cst)</td></tr>
///         <li>Default value: Uniform:0:200</td></tr>
///         <li>Description: A random variable which represents the x position of a position in a random rectangle.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomRectanglePositionY RandomRectanglePositionY
///    <ul>
///         <li>Type: (Uniform:min:max|Constant:cst)</td></tr>
///         <li>Default value: Uniform:0:200</td></tr>
///         <li>Description: A random variable which represents the y position of a position in a random rectangle.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomDiscPositionTheta RandomDiscPositionTheta
///    <ul>
///         <li>Type: (Uniform:min:max|Constant:cst)</td></tr>
///         <li>Default value: Uniform:0:6.2830</td></tr>
///         <li>Description: A random variable which represents the angle (gradients) of a position in a random disc.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomDiscPositionRho RandomDiscPositionRho
///    <ul>
///         <li>Type: (Uniform:min:max|Constant:cst)</td></tr>
///         <li>Default value: Uniform:0:200</td></tr>
///         <li>Description: A random variable which represents the radius of a position in a random disc.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomDiscPositionX RandomDiscPositionX
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 0</td></tr>
///         <li>Description: The x coordinate of the center of the random position disc.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRandomDiscPositionY RandomDiscPositionY
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 0</td></tr>
///         <li>Description: The y coordinate of the center of the random position disc.</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueOnOffApplicationDataRate OnOffApplicationDataRate
///    <ul>
///         <li>Type: (b/s|kb/s|Mb/s)</td></tr>
///         <li>Default value: 500kb/s</td></tr>
///         <li>Description: The data rate in on state for OnOffApplication</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueOnOffApplicationPacketSize OnOffApplicationPacketSize
///    <ul>
///         <li>Type: uint32_t(1:4294967295)</td></tr>
///         <li>Default value: 512</td></tr>
///         <li>Description: The size of packets sent in on state for OnOffApplication</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValuePointToPointLinkDataRate PointToPointLinkDataRate
///    <ul>
///         <li>Type: (b/s|kb/s|Mb/s)</td></tr>
///         <li>Default value: 10000Mb/s</td></tr>
///         <li>Description: The default data rate for point to point links</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueQueue Queue
///    <ul>
///         <li>Type: (DropTailQueue)</td></tr>
///         <li>Default value: DropTailQueue</td></tr>
///         <li>Description: Packet Queue</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueErrorModel ErrorModel
///    <ul>
///         <li>Type: (RateErrorModel|ListErrorModel)</td></tr>
///         <li>Default value: RateErrorModel</td></tr>
///         <li>Description: Error Model</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRateErrorModelErrorRate RateErrorModelErrorRate
///    <ul>
///         <li>Type: double(-1.79769e+308:1.79769e+308)</td></tr>
///         <li>Default value: 0</td></tr>
///         <li>Description: The error rate for the error model</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueRateErrorModelErrorUnit RateErrorModelErrorUnit
///    <ul>
///         <li>Type: (EU_BYTE|EU_PKT|EU_BIT)</td></tr>
///         <li>Default value: EU_BYTE</td></tr>
///         <li>Description: The error unit for this error model</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueScheduler Scheduler
///    <ul>
///         <li>Type: (Map|BinaryHeap|List)</td></tr>
///         <li>Default value: Map</td></tr>
///         <li>Description: Event Scheduler algorithm</td></tr>
///    </ul>
///  </li>
///  <li> \anchor DefaultValueTimeStepPrecision TimeStepPrecision
///    <ul>
///         <li>Type: (NS|S|MS|US|PS|FS)</td></tr>
///         <li>Default value: NS</td></tr>
///         <li>Description: The time unit of the internal 64 bit integer time.</td></tr>
///    </ul>
///  </li>
/// </ul>
